@@ -159,7 +159,7 @@ keyword_model_get_iter (GtkTreeModel *tree_model,
                 return FALSE;
         }
 
-        if (indices[0] >= priv->keywords.length) {
+        if (indices[0] >= (gint)priv->keywords.length) {
                 return FALSE;
         }
 
@@ -355,12 +355,26 @@ dh_keyword_model_tree_model_init (GtkTreeModelIface *iface)
         iface->iter_parent     = keyword_model_iter_parent;
 }
 
+/**
+ * dh_keyword_model_new:
+ *
+ * Create a new #DhKeywordModel object.
+ *
+ * Returns: a new #DhKeywordModel object
+ */
 DhKeywordModel *
 dh_keyword_model_new (void)
 {
         return g_object_new (DH_TYPE_KEYWORD_MODEL, NULL);
 }
 
+/**
+ * dh_keyword_model_set_words:
+ * @model: a #DhKeywordModel object
+ * @book_manager: a #DhBookManager to analyze
+ *
+ * Set the #DhBookManager object on which words are analyzed.
+ */
 void
 dh_keyword_model_set_words (DhKeywordModel *model,
                             DhBookManager  *book_manager)
@@ -659,7 +673,7 @@ keyword_model_search (DhKeywordModel  *model,
                       DhLink         **exact_link)
 {
         SearchSettings settings;
-        gint max_hits = MAX_HITS;
+        guint max_hits = MAX_HITS;
         GQueue *in_book = NULL;
         GQueue *other_books = NULL;
         DhLink *in_book_exact_link = NULL;
@@ -685,7 +699,7 @@ keyword_model_search (DhKeywordModel  *model,
                  * more than MAX_HITS keywords, and the page link may be
                  * the last one in the list, but we always want to get it.
                  */
-                max_hits = G_MAXINT;
+                max_hits = G_MAXUINT;
         }
 
         /* If book_id given; first look for prefixed items in the given book id */
@@ -965,6 +979,18 @@ set_keywords_list (DhKeywordModel *model,
         }
 }
 
+/**
+ * dh_keyword_model_filter:
+ * @model: a #DhKeywordModel object
+ * @search_string: a search query
+ * @book_id: (nullable): the id of a specific book or %NULL for all books
+ * @language: (nullable): the name of a language or %NULL for all languages
+ *
+ * Find the book matching the given criteria.
+ *
+ * Returns: (nullable) (transfer none): the corresponding #DhLink or %NULL if
+ * no link corresponding to the criteria is found
+ */
 DhLink *
 dh_keyword_model_filter (DhKeywordModel *model,
                          const gchar    *search_string,
