@@ -338,8 +338,13 @@ sidebar_entry_insert_text_cb (GtkEntry    *entry,
                         g_idle_add ((GSourceFunc) sidebar_complete_idle_cb, sidebar);
 }
 
-/******************************************************************************/
-
+/**
+ * dh_sidebar_set_search_string:
+ * @sidebar: a #DhSidebar object
+ * @str: the string to seach
+ *
+ * Set the search string to @str.
+ */
 void
 dh_sidebar_set_search_string (DhSidebar   *sidebar,
                               const gchar *str)
@@ -355,8 +360,12 @@ dh_sidebar_set_search_string (DhSidebar   *sidebar,
         gtk_editable_select_region (GTK_EDITABLE (priv->entry), -1, -1);
 }
 
-/******************************************************************************/
-
+/**
+ * dh_sidebar_set_search_focus:
+ * @sidebar: a #DhSidebar object
+ *
+ * Give the focus to the search entry.
+ */
 void
 dh_sidebar_set_search_focus (DhSidebar *sidebar)
 {
@@ -365,8 +374,6 @@ dh_sidebar_set_search_focus (DhSidebar *sidebar)
         gtk_widget_grab_focus (GTK_WIDGET (priv->entry));
 }
 
-/******************************************************************************/
-
 static void
 hitlist_cell_data_func (GtkTreeViewColumn *tree_column,
                         GtkCellRenderer   *cell,
@@ -419,8 +426,6 @@ hitlist_cell_data_func (GtkTreeViewColumn *tree_column,
         g_free (name);
 }
 
-/******************************************************************************/
-
 static void
 sidebar_book_tree_link_selected_cb (DhBookTree *book_tree,
                                     DhLink     *link,
@@ -429,6 +434,14 @@ sidebar_book_tree_link_selected_cb (DhBookTree *book_tree,
         g_signal_emit (sidebar, signals[LINK_SELECTED], 0, link);
 }
 
+/**
+ * dh_sidebar_get_selected_book:
+ * @sidebar: a #DhSidebar object
+ *
+ * Get the link pointing to the selected book.
+ *
+ * Returns: (nullable) (transfer full): the selected book link
+ */
 DhLink *
 dh_sidebar_get_selected_book (DhSidebar *sidebar)
 {
@@ -441,6 +454,13 @@ dh_sidebar_get_selected_book (DhSidebar *sidebar)
         return dh_book_tree_get_selected_book (priv->book_tree);
 }
 
+/**
+ * dh_sidebar_select_uri:
+ * @sidebar: a #DhSidebar object
+ * @uri: the uri to select
+ *
+ * Select the given @uri.
+ */
 void
 dh_sidebar_select_uri (DhSidebar   *sidebar,
                        const gchar *uri)
@@ -454,8 +474,14 @@ dh_sidebar_select_uri (DhSidebar   *sidebar,
         dh_book_tree_select_uri (priv->book_tree, uri);
 }
 
-/******************************************************************************/
-
+/**
+ * dh_sidebar_new:
+ * @book_manager: the book manager
+ *
+ * Create a new #DhSidebar object.
+ *
+ * Returns: a new #DhSidebar object
+ */
 GtkWidget *
 dh_sidebar_new (DhBookManager *book_manager)
 {
@@ -491,7 +517,7 @@ dh_sidebar_finalize (GObject *object)
 {
         DhSidebarPrivate *priv = dh_sidebar_get_instance_private (DH_SIDEBAR (object));
 
-        g_completion_free (priv->completion);
+        g_clear_pointer (&priv->completion, g_completion_free);
 
         G_OBJECT_CLASS (dh_sidebar_parent_class)->finalize (object);
 }
@@ -676,6 +702,11 @@ dh_sidebar_class_init (DhSidebarClass *klass)
                                                               G_PARAM_READWRITE |
                                                               G_PARAM_CONSTRUCT_ONLY));
 
+        /**
+         * DhSidebar::link-selected:
+         * @sidebar: a #DhSidebar object
+         * @link: the selected #DhLink
+         */
         signals[LINK_SELECTED] =
                 g_signal_new ("link_selected",
                               G_TYPE_FROM_CLASS (klass),
